<?php

namespace App\Notifications\Netmails\Areafix;

use Illuminate\Support\Facades\Log;

use App\Notifications\Netmails;
use App\Models\Netmail;
use App\Traits\{MessagePath,PageTemplate};

class NotConfiguredHere extends Netmails
{
	use MessagePath,PageTemplate;

	private const LOGKEY = 'NCH';

	private Netmail $mo;

	/**
	 * Reply to a areafix, but the system isnt configured here.
	 *
	 * @param Netmail $mo
	 */
	public function __construct(Netmail $mo)
	{
		parent::__construct();

		$this->mo = $mo;
	}

	/**
	 * Get the mail representation of the notification.
	 *
	 * @param mixed $notifiable
	 * @return Netmail
	 * @throws \Exception
	 */
	public function toNetmail(object $notifiable): Netmail
	{
		$o = $this->setupNetmail($notifiable);
		$ao = $notifiable->routeNotificationFor(static::via);

		Log::info(sprintf('%s:+ Responding to areafix for a node [%s] not configured here',self::LOGKEY,$ao->ftn));

		$o->to = $this->mo->from;
		$o->replyid = $this->mo->msgid;
		$o->subject = 'Areafix - Not Configured Here';

		// Message
		$msg = $this->page(FALSE,'Areafix');

		$msg->addText("Your areafix request has been received, but unfortunately you are not configured here.\r\r");
		$msg->addText(sprintf("If you want to receive mail from this system, please register/link your BBS via the web UI. Head over to %s. Feel free to netmail if you need help.\r\r",config('app.url')));

		$msg->addText($this->message_path($this->mo));

		$o->msg = $msg->render();
		$o->tagline = 'Why did the robot cross the road? The chicken programmed it.';

		$o->save();

		return $o;
	}
}